flutter_web_auth_2 library

Classes

FlutterWebAuth2
Provides all the functions you - as a user - should access.
FlutterWebAuth2Options
Provides configuration options for calls to authenticate.
FlutterWebAuth2UnsupportedPlugin
Implements the plugin interface for unsupported platforms (just throws errors).

Constants

defaultIntentFlags → const int
Default intent flags for opening the custom tabs intent on Android.
ephemeralIntentFlags → const int
"Ephemeral" intent flags for opening the custom tabs intent on Android.