intentFlags property

int intentFlags
final

Only has an effect on Android! Can be used to configure the intent flags for the custom tabs intent. Possible values can be found here or by using the flags from the Flag class from android_intent_plus.

Implementation

final int intentFlags;