timeout property
Only has an effect on Linux, Web, and Windows! Can be used to specify a timeout in seconds when the authentication shall be deemed unsuccessful. An error will be thrown in order to abort the authentication process.
Implementation
final int timeout;